@@ -54,11 +54,11 @@ def parse_args(args=None):
         nargs='+',
         help='''Production number of symptomatic infectors, should be specified as a single
             fixed number, or 2.5%% and 97.5%% quantile of a normal distribution from which individual
-            production number will be drawn. Multipliers are allowed to specify symptomatic r0 for
-            each group. This parameter reflects the infectivity of virus carrier measured
-            by the average number of individuals one infected individual "would" infect if
-            infectivity is not blocked by for example quarantine and susceptibility of
-            infectees.'''
+            production number will be drawn. Multipliers are allowed to adjust impact of social
+            distancing or mask for each group. This parameter reflects the infectivity of virus
+            carrier measured by the average number of individuals one infected individual "would"
+            infect if infectivity is not blocked by for example quarantine and susceptibility of
+            infectees. Note that viral loads are only affected by baseline R0, not multipliers.'''
     )
     parser.add_argument(
         '--asymptomatic-r0',
@@ -107,6 +107,12 @@ def parse_args(args=None):
         help='''Number of replicates to simulate. An ID starting from
               1 will be assinged to each replicate and as the first columns
               in the log file.''')
+    parser.add_argument(
+        '--resume',
+        action='store_true',
+        help='''If true, resume from last interrupted simulations. Existing logfile will not
+            be erased if exists. Note that this option does not check if the previous simulations
+            use the same options, or if they have corrected completed.''')
     parser.add_argument(
         '--handle-symptomatic',
         nargs='*',
@@ -191,7 +197,7 @@ class FilteredStringIO(StringIO):
         self._track_events = track_events
         if self._track_events is not None:
             self._track_events = set(self._track_events)
-            for evt in ('START', 'ERRPR'):
+            for evt in ('START', 'ERROR', 'END'):
                 if evt not in self._track_events:
                     self._track_events.add(evt)
 
@@ -280,13 +286,17 @@ def main(argv=None):
             )
 
     completed_ids = set()
-    append_mode = os.path.isfile(args.logfile)
+    append_mode = os.path.isfile(args.logfile) and args.resume
     has_header = False
     if append_mode:
         with open(args.logfile, 'r') as lf:
+            last_id = 'xxxx'
             for line in lf:
                 try:
-                    id = int(line.split('\t', 1)[0])
+                    if line.startswith(last_id):
+                        continue
+                    last_id = line.split('\t', 1)[0] + '\t'
+                    id = int(last_id)
                     if id <= args.repeats:
                         completed_ids.add(id)
                 except:
